==> cp-vue-cli-1.0.1.tgz: package/example/vue.config.js <==
// 导入模块
const path = require("path");
const resolve = (dir) => path.resolve(__dirname, dir);
const { VueLoaderPlugin } = require("vue-loader");
const HtmlWebpackPlugin = require("html-webpack-plugin");
const MiniCssExtractPlugin = require("mini-css-extract-plugin");

// 导出配置
module.exports = {
  resolve: {
    // 设置别名
    alias: {
      "@": resolve("src"), // 这样配置后 @ 可以指向 src 目录
    },
  },
  // 开发服务器配置
  devServer: {
    open: true, // cnpm run dev 之后自动打开浏览器
    port: 8081, // 默认端口
    proxy: {
      // 任意名称: {
      //   target: "真实请求网址",
      //   changeOrigin: true, // 是否允许跨域
      //   secure: false, // 关闭SSL证书验证https协议接口需要改成true
      //   pathRewrite: {
      //     // 重写路径请求
      //     "^/任意名称": "", //路径重写
      //   },
      // },
      "/api": {
        target: "https://www.baidu.com",
        changeOrigin: true, // 是否允许跨域
        secure: false, // 关闭SSL证书验证https协议接口需要改成true
        pathRewrite: {
          // 重写路径请求
          "^/api": "", //路径重写
        },
      },
      // ....
    },
  },
  // 入口
  entry: "./src/main.js",
  // 出口
  output: {
    path: path.resolve(__dirname, "dist"),
    filename: "js/[name].[chunkhash:7].js",
  },
  // 运行在整个项目的编译时期
  // plugin插件：赋予了webpack各种灵活的功能，如打包优化，资源管理，环境变量，注入等，目的是为了解决loader无法实现的功能。
  plugins: [
    new VueLoaderPlugin(),
    //说明：功能让webpack变得更强
    //作用：给public/index.js自动引入打包后的js等文件
    //new HtmlWebpackPlugin()
    new HtmlWebpackPlugin({
      // 自定义变量
      title: "仿写vue脚手架学习",
      desc: "神龙教主、洪福齐天、寿与天齐",
      // 输出到dist下面的名称、默认index.html
      filename: "index.html",
      // 模板文件
      template: "public/index.html",
    }),
    //说明：功能让webpack变得更强
    //作用：CSS单独文件存放
    new MiniCssExtractPlugin({
      filename: "css/[name].css",
    }),
    // ...
  ],
  // 运行在项目打包之前
  // loader：是文件加载器，能够加载资源文件，并对文件进行一些处理，如编译，压缩 等，最终一起打包到指定的文件中。
  module: {
    rules: [
      // 处理vue文件
      {
        test: /\.vue$/,
        loader: "vue-loader",
      },
      // 处理css文件：单独打包存放css文件
      {
        test: /\.css$/i,
        // use: ["style-loader", "css-loader"],
        use: [MiniCssExtractPlugin.loader, "css-loader"],
      },
      // 处理scss文件
      {
        test: /\.s[ac]ss$/i,
        // use: ['style-loader', 'css-loader', 'sass-loader',],
        use: [MiniCssExtractPlugin.loader, "css-loader", "sass-loader"],
      },
      // 处理图片文件
      // {
      //   test: /\.(png|jpe?g|gif)$/i,
      //   loader: "file-loader",
      //   options: {
      //     name: "imgs/[name].[ext]",
      //     publicPath: "/",
      //   },
      // },
      {
        test: /\.(png|jpg|gif)$/i,
        use: [
          {
            loader: "url-loader",
            options: {
              limit: 1024 * 1024 * 1, // 1M   图片超过指定字节不编码
              name: "imgs/[name].[ext]",
              publicPath: "/",
            },
          },
        ],
      },
      // 处理逻辑文件
      {
        test: /\.m?js$/,
        exclude: /(node_modules|bower_components)/,
        use: {
          loader: "babel-loader",
          options: {
            presets: ["@babel/preset-env"],
            plugins: ["@babel/plugin-transform-runtime"],
          },
        },
      },
      // ...
    ],
  },
};

==> cp-vue-cli-1.0.2.tgz: package/example/vue.config.js <==
// 导入模块
const path = require("path");
const resolve = (dir) => path.resolve(__dirname, dir);
const { VueLoaderPlugin } = require("vue-loader");
const HtmlWebpackPlugin = require("html-webpack-plugin");
const MiniCssExtractPlugin = require("mini-css-extract-plugin");

// 导出配置
module.exports = {
  resolve: {
    // 设置别名
    alias: {
      '@': resolve('src'), // 这样配置后 @ 可以指向 src 目录
    },
  },
  // 开发服务器配置
  devServer: {
    open: true, // cnpm run dev 之后自动打开浏览器
    port: 8081, // 默认端口
    proxy: {
      // 任意名称: {
      //   target: "真实请求网址",
      //   changeOrigin: true, // 是否允许跨域
      //   secure: false, // 关闭SSL证书验证https协议接口需要改成true
      //   pathRewrite: {
      //     // 重写路径请求
      //     "^/任意名称": "", //路径重写
      //   },
      // },
      '/api': {
        target: 'https://www.baidu.com',
        changeOrigin: true, // 是否允许跨域
        secure: false, // 关闭SSL证书验证https协议接口需要改成true
        pathRewrite: {
          // 重写路径请求
          '^/api': '', //路径重写
        },
      },
      // ....
    },
  },
  // 入口
  entry: './src/main.js',
  // 出口
  output: {
    path: path.resolve(__dirname, 'dist'),
    filename: 'js/[name].[chunkhash:7].js',
  },
  // 运行在整个项目的编译时期
  // plugin插件：赋予了webpack各种灵活的功能，如打包优化，资源管理，环境变量，注入等，目的是为了解决loader无法实现的功能。
  plugins: [
    new VueLoaderPlugin(),
    //说明：功能让webpack变得更强
    //作用：给public/index.js自动引入打包后的js等文件
    //new HtmlWebpackPlugin()
    new HtmlWebpackPlugin({
      // 自定义变量
      title: '仿写vue脚手架学习',
      desc: '仿写vue脚手架学习',
      // 输出到dist下面的名称、默认index.html
      filename: 'index.html',
      // 模板文件
      template: 'public/index.html',
    }),
    //说明：功能让webpack变得更强
    //作用：CSS单独文件存放
    new MiniCssExtractPlugin({
      filename: 'css/[name].css',
    }),
    // ...
  ],
  // 运行在项目打包之前
  // loader：是文件加载器，能够加载资源文件，并对文件进行一些处理，如编译，压缩 等，最终一起打包到指定的文件中。
  module: {
    rules: [
      // 处理vue文件
      {
        test: /\.vue$/,
        loader: 'vue-loader',
      },
      // 处理css文件：单独打包存放css文件
      {
        test: /\.css$/i,
        // use: ["style-loader", "css-loader"],
        use: [MiniCssExtractPlugin.loader, 'css-loader'],
      },
      // 处理scss文件
      {
        test: /\.s[ac]ss$/i,
        // use: ['style-loader', 'css-loader', 'sass-loader',],
        use: [MiniCssExtractPlugin.loader, 'css-loader', 'sass-loader'],
      },
      // 处理图片文件
      // {
      //   test: /\.(png|jpe?g|gif)$/i,
      //   loader: "file-loader",
      //   options: {
      //     name: "imgs/[name].[ext]",
      //     publicPath: "/",
      //   },
      // },
      {
        test: /\.(png|jpg|gif)$/i,
        use: [
          {
            loader: 'url-loader',
            options: {
              limit: 1024 * 1024 * 1, // 1M   图片超过指定字节不编码
              name: 'imgs/[name].[ext]',
              publicPath: '/',
            },
          },
        ],
      },
      // 处理逻辑文件
      {
        test: /\.m?js$/,
        exclude: /(node_modules|bower_components)/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: ['@babel/preset-env'],
            plugins: ['@babel/plugin-transform-runtime'],
          },
        },
      },
      // ...
    ],
  },
}
